@@ -1,22 +1,32 @@
 # -*- coding: utf-8 -*-
 import os
-import imp
+try:
+    import imp
+except ImportError:  # py12
+    imp = None
+    import importlib
+    import importlib.machinery
 
 
 def action_caller(service):
     cur_path = os.path.dirname(os.path.abspath(__file__))
-    fp, pathname, desc = imp.find_module(service, [cur_path])
-    mod = imp.load_module("tccli.services." + service, fp, pathname, desc)
+    if imp:
+        fp, pathname, desc = imp.find_module(service, [cur_path])
+        mod = imp.load_module("tccli.services." + service, fp, pathname, desc)
+    else:
+        spec = importlib.machinery.PathFinder().find_spec(service, [cur_path])
+        mod = importlib.util.module_from_spec(spec)
+        spec.loader.exec_module(mod)
     return mod.action_caller
 
 
 SERVICE_VERSIONS = {
-    "aa": [
-        "2020-02-24"
-    ],
     "aai": [
         "2018-05-22"
     ],
+    "aca": [
+        "2021-03-23"
+    ],
     "acp": [
         "2022-01-05"
     ],
@@ -29,6 +39,9 @@ SERVICE_VERSIONS = {
     "afc": [
         "2020-02-26"
     ],
+    "ai3d": [
+        "2025-05-13"
+    ],
     "aiart": [
         "2022-12-29"
     ],
@@ -45,9 +58,6 @@ SERVICE_VERSIONS = {
     "antiddos": [
         "2020-03-09"
     ],
-    "apcas": [
-        "2020-11-27"
-    ],
     "ape": [
         "2020-05-13"
     ],
@@ -78,6 +88,9 @@ SERVICE_VERSIONS = {
     "bda": [
         "2020-03-24"
     ],
+    "bh": [
+        "2023-04-18"
+    ],
     "bi": [
         "2022-01-05"
     ],
@@ -116,6 +129,9 @@ SERVICE_VERSIONS = {
         "2021-05-14",
         "2021-03-03"
     ],
+    "ca": [
+        "2023-02-28"
+    ],
     "cam": [
         "2019-01-16"
     ],
@@ -125,9 +141,6 @@ SERVICE_VERSIONS = {
     "car": [
         "2022-01-10"
     ],
-    "casb": [
-        "2020-05-07"
-    ],
     "cat": [
         "2018-04-09"
     ],
@@ -152,6 +165,15 @@ SERVICE_VERSIONS = {
     "cdwch": [
         "2020-09-15"
     ],
+    "cdwdoris": [
+        "2021-12-28"
+    ],
+    "cdwpg": [
+        "2020-12-30"
+    ],
+    "cdz": [
+        "2022-11-23"
+    ],
     "cfg": [
         "2021-08-20"
     ],
@@ -161,6 +183,9 @@ SERVICE_VERSIONS = {
     "cfw": [
         "2019-09-04"
     ],
+    "chc": [
+        "2023-04-18"
+    ],
     "chdfs": [
         "2020-11-12",
         "2019-07-18"
@@ -175,15 +200,15 @@ SERVICE_VERSIONS = {
     "cim": [
         "2019-03-18"
     ],
-    "cis": [
-        "2018-04-08"
-    ],
     "ckafka": [
         "2019-08-19"
     ],
     "clb": [
         "2018-03-17"
     ],
+    "cloudapp": [
+        "2022-05-30"
+    ],
     "cloudaudit": [
         "2019-03-19"
     ],
@@ -191,7 +216,7 @@ SERVICE_VERSIONS = {
         "2019-11-12"
     ],
     "cloudstudio": [
-        "2021-05-24"
+        "2023-05-08"
     ],
     "cls": [
         "2020-10-16"
@@ -205,11 +230,23 @@ SERVICE_VERSIONS = {
     "cms": [
         "2019-03-21"
     ],
+    "config": [
+        "2022-08-02"
+    ],
+    "controlcenter": [
+        "2023-01-10"
+    ],
     "cpdp": [
         "2019-08-20"
     ],
-    "cr": [
-        "2018-03-21"
+    "csip": [
+        "2022-11-21"
+    ],
+    "csxg": [
+        "2023-03-03"
+    ],
+    "ctem": [
+        "2023-11-28"
     ],
     "cvm": [
         "2017-03-12"
@@ -226,9 +263,6 @@ SERVICE_VERSIONS = {
     "dasb": [
         "2019-10-18"
     ],
-    "dataintegration": [
-        "2022-06-13"
-    ],
     "dayu": [
         "2018-07-09"
     ],
@@ -260,8 +294,8 @@ SERVICE_VERSIONS = {
     "ds": [
         "2018-05-23"
     ],
-    "dtf": [
-        "2020-05-06"
+    "dsgc": [
+        "2019-07-23"
     ],
     "dts": [
         "2021-12-06",
@@ -290,7 +324,8 @@ SERVICE_VERSIONS = {
         "2019-01-03"
     ],
     "es": [
-        "2018-04-16"
+        "2018-04-16",
+        "2025-01-01"
     ],
     "ess": [
         "2020-11-11"
@@ -321,28 +356,34 @@ SERVICE_VERSIONS = {
     "goosefs": [
         "2022-05-19"
     ],
-    "gpm": [
-        "2020-08-20"
-    ],
     "gs": [
         "2019-11-18"
     ],
-    "gse": [
-        "2019-11-12"
+    "gwlb": [
+        "2024-09-06"
     ],
     "habo": [
         "2018-12-03"
     ],
+    "hai": [
+        "2023-08-12"
+    ],
     "hasim": [
         "2021-07-16"
     ],
     "hcm": [
         "2018-11-06"
     ],
+    "hunyuan": [
+        "2023-09-01"
+    ],
     "iai": [
         "2020-03-03",
         "2018-03-01"
     ],
+    "iap": [
+        "2024-07-13"
+    ],
     "ic": [
         "2019-03-07"
     ],
@@ -352,16 +393,19 @@ SERVICE_VERSIONS = {
     "ie": [
         "2020-03-04"
     ],
-    "iecp": [
-        "2021-09-14"
+    "ig": [
+        "2021-05-18"
     ],
-    "iir": [
-        "2020-04-17"
+    "igtm": [
+        "2023-10-24"
     ],
     "ims": [
         "2020-12-29",
         "2020-07-13"
     ],
+    "ioa": [
+        "2022-06-01"
+    ],
     "iot": [
         "2018-01-23"
     ],
@@ -372,9 +416,6 @@ SERVICE_VERSIONS = {
     "iotexplorer": [
         "2019-04-23"
     ],
-    "iottid": [
-        "2019-04-11"
-    ],
     "iotvideo": [
         "2021-11-25",
         "2020-12-15",
@@ -387,6 +428,9 @@ SERVICE_VERSIONS = {
         "2022-08-05",
         "2022-03-24"
     ],
+    "iss": [
+        "2023-05-17"
+    ],
     "ivld": [
         "2021-09-03"
     ],
@@ -405,11 +449,17 @@ SERVICE_VERSIONS = {
     "live": [
         "2018-08-01"
     ],
+    "lke": [
+        "2023-11-30"
+    ],
+    "lkeap": [
+        "2024-05-22"
+    ],
     "lowcode": [
         "2021-01-08"
     ],
-    "lp": [
-        "2020-02-24"
+    "mall": [
+        "2023-05-18"
     ],
     "mariadb": [
         "2017-03-12"
@@ -420,10 +470,6 @@ SERVICE_VERSIONS = {
     "memcached": [
         "2019-03-18"
     ],
-    "mgobe": [
-        "2020-10-14",
-        "2019-09-29"
-    ],
     "mmps": [
         "2020-07-10"
     ],
@@ -435,11 +481,15 @@ SERVICE_VERSIONS = {
         "2018-04-08"
     ],
     "monitor": [
-        "2018-07-24"
+        "2018-07-24",
+        "2023-06-16"
     ],
     "mps": [
         "2019-06-12"
     ],
+    "mqtt": [
+        "2024-05-16"
+    ],
     "mrs": [
         "2020-09-10"
     ],
@@ -449,9 +499,6 @@ SERVICE_VERSIONS = {
     "msp": [
         "2018-03-19"
     ],
-    "mvj": [
-        "2019-09-26"
-    ],
     "nlp": [
         "2019-04-08"
     ],
@@ -474,9 +521,6 @@ SERVICE_VERSIONS = {
     "partners": [
         "2018-03-21"
     ],
-    "pds": [
-        "2021-07-01"
-    ],
     "postgres": [
         "2017-03-12"
     ],
@@ -495,18 +539,15 @@ SERVICE_VERSIONS = {
     "region": [
         "2022-06-27"
     ],
-    "rkp": [
-        "2019-12-09"
-    ],
-    "rp": [
-        "2020-02-24"
-    ],
     "rum": [
         "2021-06-22"
     ],
     "scf": [
         "2018-04-16"
     ],
+    "securitylake": [
+        "2024-01-17"
+    ],
     "ses": [
         "2020-10-02"
     ],
@@ -516,9 +557,6 @@ SERVICE_VERSIONS = {
     "smop": [
         "2020-12-03"
     ],
-    "smpn": [
-        "2019-08-22"
-    ],
     "sms": [
         "2021-01-11",
         "2019-07-11"
@@ -526,9 +564,6 @@ SERVICE_VERSIONS = {
     "soe": [
         "2018-07-24"
     ],
-    "solar": [
-        "2018-10-11"
-    ],
     "sqlserver": [
         "2018-03-28"
     ],
@@ -547,27 +582,21 @@ SERVICE_VERSIONS = {
     "sts": [
         "2018-08-13"
     ],
+    "svp": [
+        "2024-01-25"
+    ],
     "taf": [
         "2020-02-10"
     ],
     "tag": [
         "2018-08-13"
     ],
-    "tan": [
-        "2022-04-20"
-    ],
     "tat": [
         "2020-10-28"
     ],
-    "tav": [
-        "2019-01-18"
-    ],
     "tbaas": [
         "2018-04-16"
     ],
-    "tbm": [
-        "2018-01-29"
-    ],
     "tbp": [
         "2019-06-27",
         "2019-03-11"
@@ -581,11 +610,11 @@ SERVICE_VERSIONS = {
     "tcbr": [
         "2022-02-17"
     ],
-    "tcex": [
-        "2020-07-27"
+    "tccatalog": [
+        "2024-10-24"
     ],
-    "tci": [
-        "2019-03-18"
+    "tchd": [
+        "2023-03-06"
     ],
     "tcm": [
         "2021-04-13"
@@ -624,18 +653,6 @@ SERVICE_VERSIONS = {
     "tia": [
         "2018-02-26"
     ],
-    "tic": [
-        "2020-11-17"
-    ],
-    "ticm": [
-        "2018-11-27"
-    ],
-    "tics": [
-        "2018-11-15"
-    ],
-    "tiems": [
-        "2019-04-16"
-    ],
     "tiia": [
         "2019-05-29"
     ],
@@ -647,7 +664,8 @@ SERVICE_VERSIONS = {
         "2019-09-19"
     ],
     "tke": [
-        "2018-05-25"
+        "2018-05-25",
+        "2022-05-01"
     ],
     "tkgdq": [
         "2019-04-11"
@@ -659,8 +677,14 @@ SERVICE_VERSIONS = {
     "tmt": [
         "2018-03-21"
     ],
-    "trdp": [
-        "2022-07-26"
+    "tourism": [
+        "2023-02-15"
+    ],
+    "trabbit": [
+        "2023-04-18"
+    ],
+    "trocket": [
+        "2023-03-08"
     ],
     "trp": [
         "2021-05-15"
@@ -677,6 +701,9 @@ SERVICE_VERSIONS = {
     "tsf": [
         "2018-03-26"
     ],
+    "tsi": [
+        "2021-03-25"
+    ],
     "tsw": [
         "2021-04-12",
         "2020-09-24"
@@ -684,8 +711,17 @@ SERVICE_VERSIONS = {
     "tts": [
         "2019-08-23"
     ],
-    "ump": [
-        "2020-09-18"
+    "vcg": [
+        "2024-04-04"
+    ],
+    "vclm": [
+        "2024-05-23"
+    ],
+    "vcube": [
+        "2022-04-10"
+    ],
+    "vdb": [
+        "2023-06-16"
     ],
     "vm": [
         "2021-09-22",
@@ -696,11 +732,18 @@ SERVICE_VERSIONS = {
         "2020-09-02"
     ],
     "vod": [
-        "2018-07-17"
+        "2018-07-17",
+        "2024-07-18"
     ],
     "vpc": [
         "2017-03-12"
     ],
+    "vrs": [
+        "2020-08-24"
+    ],
+    "vtc": [
+        "2024-02-23"
+    ],
     "waf": [
         "2018-01-25"
     ],
@@ -710,23 +753,20 @@ SERVICE_VERSIONS = {
     "wedata": [
         "2021-08-20"
     ],
+    "weilingwith": [
+        "2023-04-27"
+    ],
     "wss": [
         "2018-04-26"
     ],
     "yinsuda": [
         "2022-05-27"
     ],
-    "youmall": [
-        "2018-02-28"
-    ],
     "yunjing": [
         "2018-02-28"
     ],
     "yunsou": [
         "2019-11-15",
         "2018-05-04"
-    ],
-    "zj": [
-        "2019-01-21"
     ]
 }
\ No newline at end of file
